aboutsummaryrefslogtreecommitdiffstats
path: root/ram/wram.asm
diff options
context:
space:
mode:
authorRangi <35663410+Rangi42@users.noreply.github.com>2026-01-07 22:05:20 -0500
committerGitHub <noreply@github.com>2026-01-07 22:05:20 -0500
commitfe1e76466b293c83e6cd3a7d4639fb3c49da26ad (patch)
treeaba22f9f595e09024b902c08ddfdac67ee0e85f3 /ram/wram.asm
parentUpdate RGBDS to 1.0.1 (although 1.0.0 still works) (diff)
downloadpokeyellow-fe1e76466b293c83e6cd3a7d4639fb3c49da26ad.tar.gz
pokeyellow-fe1e76466b293c83e6cd3a7d4639fb3c49da26ad.tar.xz
pokeyellow-fe1e76466b293c83e6cd3a7d4639fb3c49da26ad.zip
Use macros to enforce "missable/hide/show object" constraints, and rename them to "toggleable objects" (#557)
Diffstat (limited to 'ram/wram.asm')
-rw-r--r--ram/wram.asm14
1 files changed, 7 insertions, 7 deletions
diff --git a/ram/wram.asm b/ram/wram.asm
index fff7f703..5eefaf06 100644
--- a/ram/wram.asm
+++ b/ram/wram.asm
@@ -324,7 +324,7 @@ wCheckFor180DegreeTurn:: db
ds 1
-wMissableObjectIndex:: db
+wToggleableObjectIndex:: db
wPredefID:: db
wPredefHL:: dw
@@ -1224,7 +1224,7 @@ ENDU
; money received after battle = base money × level of last enemy mon
wTrainerBaseMoney:: dw ; BCD
-wMissableObjectCounter:: db
+wToggleableObjectCounter:: db
ds 1
@@ -1909,9 +1909,9 @@ wUnusedMapVariable:: db
wPlayerCoins:: dw ; BCD
-; bit array of missable objects. set = removed
-wMissableObjectFlags:: flag_array $100
-wMissableObjectFlagsEnd::
+; bit array of toggleable objects; bit set = toggled off
+wToggleableObjectFlags:: flag_array $100
+wToggleableObjectFlagsEnd::
ds 7
@@ -1920,9 +1920,9 @@ wSavedSpriteImageIndex:: db
; each entry consists of 2 bytes
; * the sprite ID (depending on the current map)
; * the missable object index (global, used for wMissableObjectFlags)
; terminated with $FF
-wMissableObjectList:: ds 16 * 2 + 1
+wToggleableObjectList:: ds 16 * 2 + 1
ds 1
@@ -1920,9 +1920,9 @@ wSavedSpriteImageIndex:: db
; each entry consists of 2 bytes
; * the sprite ID (depending on the current map)
-; * the missable object index (global, used for wMissableObjectFlags)
+; * the toggleable object index (global, used for wToggleableObjectFlags)
; terminated with $FF